pygeodesy.ltp

Package pygeodesy :: Module ltp |
[frames] | no frames]

# Module ltp

Local Tangent Plane (LTP) and local cartesian coordinates.

Local cartesian and local tangent plane classes LocalCartesian, approximations ChLVa and ChLVe and Ltp, ChLV, LocalError, Attitude and Frustum.

See Also: Local tangent plane coordinates and class LocalCartesian, transcoded from Charles Karney's C++ classLocalCartesian.

Version: 25.05.12

Classes
| Attitude The pose of a plane or camera in space.
| AttitudeError An Attitude or Attitude4Tuple issue.
| Frustum A rectangular pyramid, typically representing a camera's field-of-view (fov) and the intersection with (or projection to) a local tangent plane.
| LocalError A LocalCartesian or Ltp related issue.
| LocalCartesian Conversion between geodetic `(lat, lon, height)` and local cartesian `(x, y, z)` coordinates with geodetic origin `(lat0, lon0, height0)`, transcoded from Karney's C++ class LocalCartesian.
| Ltp A local tangent plan (LTP), a sub-class of `LocalCartesian` with (re-)configurable ECEF converter.
| ChLV Conversion between WGS84 geodetic and Swiss projection coordinates using pygeodesy.EcefKarney's Earth-Centered, Earth-Fixed (ECEF) methods.
| ChLVa Conversion between WGS84 geodetic and Swiss projection coordinates using the Approximate formulas, page 13.
| ChLVe Conversion between WGS84 geodetic and Swiss projection coordinates using the Ellipsoidal approximate formulas, pp 10-11 and Bolliger, J. pp 148-151 (also GGGS).

Functions
tyr3d(tilt=0, yaw=0, roll=0, Vector=<class 'pygeodesy.vector3d.Vector3d'>, **name_Vector_kwds) Convert an attitude pose into a (3-D) direction vector. |

Variables
| __all__ = `_ALL_LAZY.ltp`

Function Details

### tyr3d (tilt=0, yaw=0, roll=0, Vector=<class 'pygeodesy.vector3d.Vector3d'>, **name_Vector_kwds) |
Convert an attitude pose into a (3-D) direction vector. Arguments: `tilt` - Pitch, elevation from horizontal (`degrees`), negative down (clockwise rotation along and around the x-axis). `yaw` - Bearing, heading (compass `degrees360`), clockwise from North (counter-clockwise rotation along and around the z-axis). `roll` - Roll, bank (`degrees`), positive to the right and down (clockwise rotation along and around the y-axis). `Vector` - Class to return the direction vector (`Cartesian`, Vector3d or `Vector3Tuple`) or `None`. `name_Vector_kwds` - Optional `name=NN` (`str`) and optionally, additional `Vector` keyword arguments, ignored if `Vector is None`. Returns: A named `Vector` instance or if `Vector is None`, a named Vector3Tuple`(x, y, z)`. Raises: `AttitudeError` - Invalid `tilt`, `yaw` or `roll`. `TypeError` - Invalid `Vector` or `name_Vector_kwds`. See Also: Yaw, pitch, and roll rotations and function pygeodesy.hartzell argument `los`, Line-Of-Sight.